<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>LxImage::Application</name>
    <message>
        <location filename="../application.cpp" line="96"/>
        <source>Take a screenshot (deprecated, please use screengrab instead)</source>
        <translation>截图（已弃用，请改用 screengrab）</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="105"/>
        <source>DIR</source>
        <translation>文件夹</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="105"/>
        <source>Take a screenshot and save it to the directory without showing the GUI (deprecated, please use screengrab instead)</source>
        <translation>截图并将其保存到文件夹中，不显示图形界面（已弃用，请改用 screengrab）</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="111"/>
        <source>[FILE1, FILE2,...]</source>
        <translation>[文件1, 文件2,...]</translation>
    </message>
</context>
<context>
    <name>LxImage::ImageShackUpload</name>
    <message>
        <location filename="../upload/imageshackupload.cpp" line="50"/>
        <source>unknown error response</source>
        <translation>未知的错误反应</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgBBUpload</name>
    <message>
        <location filename="../upload/imgbbupload.cpp" line="44"/>
        <source>unknown error response</source>
        <translation>未知的错误响应</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgurUpload</name>
    <message>
        <location filename="../upload/imgurupload.cpp" line="47"/>
        <source>unknown error response</source>
        <translation>未知的错误反应</translation>
    </message>
</context>
<context>
    <name>LxImage::MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="207"/>
        <source>About</source>
        <translation>关于</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="208"/>
        <source>LXImage-Qt - a simple and fast image viewer

Copyright (C) 2013-2020
LXQt Project: https://lxqt-project.org

Authors:
Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</source>
        <translation>LXImage-Qt - 一个简单又快速的图片浏览器

Copyright (C) 2013-2020
LXQt Project: https://lxqt-project.org

Authors:
Hong Jen Yee (PCMan) &lt;pcman.tw@gmail.com&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="363"/>
        <source>Open File</source>
        <translation>打开文件</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="364"/>
        <location filename="../mainwindow.cpp" line="399"/>
        <source>Image files (%1)</source>
        <translation>图像文件 (%1)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="377"/>
        <source>Open directory</source>
        <translation>打开目录</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="398"/>
        <source>Save File</source>
        <translation>保存文件</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="691"/>
        <source>[*]%1 (Loading...) - Image Viewer</source>
        <translation>[*]%1 (正在加载...) - 图像查看器</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="697"/>
        <source>[*]%1 (Failed to Load) - Image Viewer</source>
        <translation>[*]%1 (加载失败) - 图像查看器</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="703"/>
        <source>[*]%1 (%2x%3) - Image Viewer</source>
        <translation>[*]%1 (%2x%3) - 图像查看器</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="749"/>
        <source>[*]Image Viewer</source>
        <translation>[*]图像查看器</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1178"/>
        <source>Thumbnails</source>
        <translation>缩略图</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1228"/>
        <source>EXIF Data</source>
        <translation>EXIF数据</translation>
    </message>
</context>
<context>
    <name>LxImage::MruMenu</name>
    <message>
        <location filename="../mrumenu.cpp" line="49"/>
        <source>&amp;Clear</source>
        <translation>清除(&amp;C)</translation>
    </message>
</context>
<context>
    <name>LxImage::PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.cpp" line="74"/>
        <source>Use a modifier key to clear a shortcut
in the editing mode.</source>
        <translation>使用修饰键清除快捷方式
在编辑模式下。</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="293"/>
        <source>&lt;b&gt;Warning: Ambiguous shortcut detected!&lt;/b&gt;</source>
        <translation>&lt;b&gt;警告：检测到有歧义的快捷方式！&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="310"/>
        <source>&lt;b&gt;Ambiguous shortcut not accepted.&lt;/b&gt;</source>
        <translation>&lt;b&gt;不接受有歧义快捷方式。&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>LxImage::SaveImageJob</name>
    <message>
        <location filename="../saveimagejob.cpp" line="54"/>
        <source>Cannot save with this image format!</source>
        <translation>无法使用此图像格式保存！</translation>
    </message>
</context>
<context>
    <name>LxImage::StatusBar</name>
    <message>
        <location filename="../statusbar.cpp" line="63"/>
        <source>Size:</source>
        <translation>尺寸：</translation>
    </message>
    <message>
        <location filename="../statusbar.cpp" line="73"/>
        <source>Path:</source>
        <translation>路径：</translation>
    </message>
</context>
<context>
    <name>LxImage::UploadDialog</name>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="52"/>
        <source>Imgur</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="53"/>
        <source>ImgBB</source>
        <translation>ImgBB</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="54"/>
        <source>ImageShack</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="137"/>
        <source>Start</source>
        <translation>开始</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="140"/>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="143"/>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="150"/>
        <source>Error</source>
        <translation>错误</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Image Viewer</source>
        <translation>图像查看器</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="188"/>
        <location filename="../mainwindow.ui" line="634"/>
        <source>Annotations Toolbar</source>
        <translation>工具栏注释</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="208"/>
        <source>&amp;About</source>
        <translation>关于(&amp;A)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="220"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="241"/>
        <source>&amp;Save</source>
        <translation>保存(&amp;S)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="244"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="253"/>
        <source>Save &amp;As</source>
        <translation>另存为(&amp;A)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="256"/>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="265"/>
        <source>&amp;Close</source>
        <translation>关闭(&amp;C)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="268"/>
        <source>Ctrl+W</source>
        <translation>Ctrl+W</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="277"/>
        <source>Zoom &amp;In</source>
        <translation>放大(&amp;I)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="289"/>
        <source>Zoom &amp;Out</source>
        <translation>缩小(&amp;O)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="292"/>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="301"/>
        <source>&amp;Copy to Clipboard</source>
        <translation>复制到剪贴板(&amp;C)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="310"/>
        <location filename="../mainwindow.ui" line="313"/>
        <source>Next File</source>
        <translation>下一个文件</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="325"/>
        <location filename="../mainwindow.ui" line="328"/>
        <source>Previous File</source>
        <translation>上一个文件</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="280"/>
        <source>Ctrl+=</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="67"/>
        <source>Open &amp;With...</source>
        <translation>用...打开(&amp;W)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="72"/>
        <source>&amp;Recently Opened Files</source>
        <translation>最近打开的文件(&amp;R)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="217"/>
        <source>&amp;Open…</source>
        <translation>&amp;打开…</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>&amp;Reload File</source>
        <translation>重新载入文件(&amp;R)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="232"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="316"/>
        <source>PgDown</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="331"/>
        <source>PgUp</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="343"/>
        <source>Original Size</source>
        <translation>原始尺寸</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="346"/>
        <source>Ctrl+0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="358"/>
        <source>&amp;Fit</source>
        <translation>适合(&amp;F)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="367"/>
        <source>&amp;Rotate Clockwise</source>
        <translation>顺时针旋转(&amp;R)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="370"/>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="379"/>
        <source>Rotate &amp;Counterclockwise</source>
        <translation>逆时针旋转(&amp;C)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="382"/>
        <source>L</source>
        <translation>L</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="387"/>
        <source>P&amp;references</source>
        <translation>偏好设置(&amp;R)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="392"/>
        <source>&amp;Print</source>
        <translation>打印(&amp;P)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="395"/>
        <source>Ctrl+P</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="404"/>
        <source>First File</source>
        <translation>第一个文件</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="407"/>
        <source>Home</source>
        <translation>起始</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="416"/>
        <source>Last File</source>
        <translation>最后一个文件</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="419"/>
        <source>End</source>
        <translation>结束</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="428"/>
        <source>&amp;New Window</source>
        <translation>新建窗口(&amp;N)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="431"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="436"/>
        <source>Flip &amp;Horizontally</source>
        <translation>水平翻转(&amp;H)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="439"/>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="448"/>
        <source>Capture Screenshot</source>
        <translation>抓取屏幕截图</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="456"/>
        <source>F&amp;ull Screen</source>
        <translation>全屏(&amp;U)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="459"/>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="464"/>
        <source>Flip &amp;Vertically</source>
        <translation>垂直翻转(&amp;V)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="467"/>
        <source>V</source>
        <translation>V</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="476"/>
        <source>&amp;Paste from Clipboard</source>
        <translation>从剪贴板粘贴(&amp;P)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="488"/>
        <source>&amp;Slide Show</source>
        <translation>幻灯片放映(&amp;S)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="497"/>
        <source>&amp;Delete</source>
        <translation>删除(&amp;D)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="500"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="508"/>
        <source>Show Thumbnails</source>
        <translation>显示缩略图</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="511"/>
        <source>T</source>
        <translation>T</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="516"/>
        <source>File Properties</source>
        <translation>文件属性</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="525"/>
        <source>Open &amp;Directory</source>
        <translation>打开目录(&amp;D)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="528"/>
        <source>Ctrl+D</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="537"/>
        <source>Upload</source>
        <translation>上传</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="540"/>
        <source>Upload the image</source>
        <translation>上传图像</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="548"/>
        <source>Show EXIF Data</source>
        <translation>显示EXIF数据</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="560"/>
        <source>No Tool</source>
        <translation>无工具</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="563"/>
        <source>Deselect all drawing tools</source>
        <translation>取消选择所有绘图工具</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="575"/>
        <source>Draw Arrow</source>
        <translation>画箭头</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="578"/>
        <source>Draw an arrow</source>
        <translation>画一个箭头</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="590"/>
        <source>Draw Rectangle</source>
        <translation>画矩形</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="593"/>
        <source>Draw a hollow rectangle</source>
        <translation>画一个中空的矩形</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="605"/>
        <source>Draw Circle</source>
        <translation>画圆形</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="608"/>
        <source>Draw a hollow circle</source>
        <translation>画一个中空的圆形</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="620"/>
        <source>Draw Number</source>
        <translation>画数字</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="623"/>
        <source>Draw incrementing numbers</source>
        <translation>画递增的数字</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="631"/>
        <source>&amp;Annotations Toolbar</source>
        <translation>&amp;工具栏注释</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="642"/>
        <location filename="../mainwindow.ui" line="645"/>
        <source>Show Outline</source>
        <translation>显示大纲</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="648"/>
        <source>O</source>
        <translation>O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="656"/>
        <source>Copy Pa&amp;th</source>
        <translation>复制路径(&amp;T)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="659"/>
        <source>Copy path</source>
        <translation>复制路径</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="668"/>
        <source>Resize</source>
        <translation>调整尺寸</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="63"/>
        <source>&amp;File</source>
        <translation>文件(&amp;F)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="95"/>
        <source>&amp;Help</source>
        <translation>帮助(&amp;H)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="101"/>
        <source>Go</source>
        <translation>转到</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="110"/>
        <source>&amp;View</source>
        <translation>查看(&amp;V)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="128"/>
        <source>&amp;Edit</source>
        <translation>编辑(&amp;E)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="153"/>
        <source>Toolbar</source>
        <translation>工具栏</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>偏好设置</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="33"/>
        <source>Icon theme:</source>
        <translation>图标主题:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="43"/>
        <source>Normal background color:</source>
        <translation>默认背景颜色:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="50"/>
        <source>Fullscreen background color:</source>
        <translation>全屏背景颜色:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="71"/>
        <source>Maximum number of recent files:</source>
        <translation>最近文件的最大数量：</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="81"/>
        <source>Slide show interval (seconds):</source>
        <translation>幻灯片放映间隔（秒）:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="95"/>
        <source>Show image outline by default</source>
        <translation>默认显示图像轮廓</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="102"/>
        <source>Show annotations toolbar by default</source>
        <translation>默认显示工具栏注释</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="109"/>
        <source>Fit images when navigating</source>
        <translation>导航时填充图像</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="117"/>
        <source>Thumbnails</source>
        <translation>缩略图</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="123"/>
        <source>Image size limit for built-in thumbnailer:</source>
        <translation>内置缩略图的图像大小限制：</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="130"/>
        <source> MiB</source>
        <translation> MiB</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="146"/>
        <source>Show thumbnails dock by default</source>
        <translation>默认显示缩略图栏</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="154"/>
        <source>Shortcuts</source>
        <translation>快捷键</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="173"/>
        <source>Action</source>
        <translation>动作</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="178"/>
        <source>Shortcut</source>
        <translation>快捷键</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="186"/>
        <source>Default</source>
        <translation>默认</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="24"/>
        <source>General</source>
        <translation>常规</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../mainwindow.cpp" line="841"/>
        <source>Error</source>
        <translation>错误</translation>
    </message>
</context>
<context>
    <name>ResizeImageDialog</name>
    <message>
        <location filename="../resizeimagedialog.ui" line="14"/>
        <source>Resize Image</source>
        <translation>调整图像尺寸</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="26"/>
        <source>Width</source>
        <translation>宽度</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="33"/>
        <source>Height</source>
        <translation>高度</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="40"/>
        <source>Current size:</source>
        <translation>当前尺寸：</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="80"/>
        <source>New size:</source>
        <translation>新尺寸：</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="93"/>
        <location filename="../resizeimagedialog.ui" line="116"/>
        <source> px</source>
        <translation> 像素</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="129"/>
        <location filename="../resizeimagedialog.ui" line="158"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="174"/>
        <source>Keep aspect ratio</source>
        <translation>保持长宽比</translation>
    </message>
</context>
<context>
    <name>ScreenshotDialog</name>
    <message>
        <location filename="../screenshotdialog.ui" line="14"/>
        <source>Screenshot</source>
        <translation>屏幕截图</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="27"/>
        <source>Take a screenshot</source>
        <translation>抓取屏幕截图</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="34"/>
        <source>Region</source>
        <translation>区域</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="40"/>
        <source>Whole screen</source>
        <translation>整个屏幕</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="50"/>
        <source>Current window only</source>
        <translation>仅当前窗口</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="57"/>
        <source>Capture an area of the screen</source>
        <translation>截取屏幕选区</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="67"/>
        <source>Include mouse cursor</source>
        <translation>包括鼠标光标</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="74"/>
        <source> sec</source>
        <translation> 秒</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="91"/>
        <source>Delay:</source>
        <translation>延迟:</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="101"/>
        <source>Include window title and frame</source>
        <translation>包括窗口标题和框架</translation>
    </message>
</context>
<context>
    <name>UploadDialog</name>
    <message>
        <location filename="../upload/uploaddialog.ui" line="14"/>
        <source>Upload</source>
        <translation>上传</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.ui" line="39"/>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
</context>
</TS>
